@@ -75,6 +75,12 @@ func TestAllowEntries(t *testing.T) {
 		{&model.Feed{ID: 1, BlocklistRules: ""}, &model.Entry{Author: "Example", Tags: []string{"example", "something else"}}, &model.User{KeepFilterEntryRules: "EntryAuthor=(?i)example\nEntryTag=(?i)Test"}, true},
 		{&model.Feed{ID: 1, BlocklistRules: ""}, &model.Entry{Author: "Different", Tags: []string{"example", "something else"}}, &model.User{KeepFilterEntryRules: "EntryAuthor=(?i)example\nEntryTag=(?i)example"}, true},
 		{&model.Feed{ID: 1, BlocklistRules: ""}, &model.Entry{Author: "Different", Tags: []string{"example", "something else"}}, &model.User{KeepFilterEntryRules: "EntryAuthor=(?i)example\nEntryTag=(?i)Test"}, false},
+		{&model.Feed{ID: 1, BlocklistRules: ""}, &model.Entry{Date: time.Now().Add(24 * time.Hour)}, &model.User{KeepFilterEntryRules: "EntryDate=future"}, true},
+		{&model.Feed{ID: 1, BlocklistRules: ""}, &model.Entry{Date: time.Now().Add(-24 * time.Hour)}, &model.User{KeepFilterEntryRules: "EntryDate=future"}, false},
+		{&model.Feed{ID: 1, BlocklistRules: ""}, &model.Entry{Date: time.Date(2024, 3, 14, 0, 0, 0, 0, time.UTC)}, &model.User{KeepFilterEntryRules: "EntryDate=before:2024-03-15"}, true},
+		{&model.Feed{ID: 1, BlocklistRules: ""}, &model.Entry{Date: time.Date(2024, 3, 16, 0, 0, 0, 0, time.UTC)}, &model.User{KeepFilterEntryRules: "EntryDate=after:2024-03-15"}, true},
+		{&model.Feed{ID: 1, BlocklistRules: ""}, &model.Entry{Date: time.Date(2024, 3, 10, 0, 0, 0, 0, time.UTC)}, &model.User{KeepFilterEntryRules: "EntryDate=between:2024-03-01,2024-03-15"}, true},
+		{&model.Feed{ID: 1, BlocklistRules: ""}, &model.Entry{Date: time.Date(2024, 2, 28, 0, 0, 0, 0, time.UTC)}, &model.User{KeepFilterEntryRules: "EntryDate=between:2024-03-01,2024-03-15"}, false},
 	}
 
 	for _, tc := range scenarios {
@@ -85,35 +91,6 @@ func TestAllowEntries(t *testing.T) {
 	}
 }
 
-func TestParseISO8601(t *testing.T) {
-	var scenarios = []struct {
-		duration string
-		expected time.Duration
-	}{
-		// Live streams and radio.
-		{"PT0M0S", 0},
-		// https://www.youtube.com/watch?v=HLrqNhgdiC0
-		{"PT6M20S", (6 * time.Minute) + (20 * time.Second)},
-		// https://www.youtube.com/watch?v=LZa5KKfqHtA
-		{"PT5M41S", (5 * time.Minute) + (41 * time.Second)},
-		// https://www.youtube.com/watch?v=yIxEEgEuhT4
-		{"PT51M52S", (51 * time.Minute) + (52 * time.Second)},
-		// https://www.youtube.com/watch?v=bpHf1XcoiFs
-		{"PT80M42S", (1 * time.Hour) + (20 * time.Minute) + (42 * time.Second)},
-	}
-
-	for _, tc := range scenarios {
-		result, err := parseISO8601(tc.duration)
-		if err != nil {
-			t.Errorf("Got an error when parsing %q: %v", tc.duration, err)
-		}
-
-		if tc.expected != result {
-			t.Errorf(`Unexpected result, got %v for duration %q`, result, tc.duration)
-		}
-	}
-}
-
 func TestIsRecentEntry(t *testing.T) {
 	parser := config.NewParser()
 	var err error
