@@ -212,7 +212,14 @@ func (s *Storage) Integration(userID int64) (*model.Integration, error) {
 			cubox_enabled,
 			cubox_api_link,
 			discord_enabled,
-			discord_webhook_link
+			discord_webhook_link,
+			slack_enabled,
+			slack_webhook_link,
+			pushover_enabled,
+			pushover_user,
+			pushover_token,
+			pushover_device,
+			pushover_prefix
 		FROM
 			integrations
 		WHERE
@@ -324,6 +331,13 @@ func (s *Storage) Integration(userID int64) (*model.Integration, error) {
 		&integration.CuboxAPILink,
 		&integration.DiscordEnabled,
 		&integration.DiscordWebhookLink,
+		&integration.SlackEnabled,
+		&integration.SlackWebhookLink,
+		&integration.PushoverEnabled,
+		&integration.PushoverUser,
+		&integration.PushoverToken,
+		&integration.PushoverDevice,
+		&integration.PushoverPrefix,
 	)
 	switch {
 	case err == sql.ErrNoRows:
@@ -443,9 +457,16 @@ func (s *Storage) UpdateIntegration(integration *model.Integration) error {
 			cubox_enabled=$100,
 			cubox_api_link=$101,
 			discord_enabled=$102,
-			discord_webhook_link=$103
+			discord_webhook_link=$103,
+			slack_enabled=$104,
+			slack_webhook_link=$105,
+			pushover_enabled=$106,
+			pushover_user=$107,
+			pushover_token=$108,
+			pushover_device=$109,
+			pushover_prefix=$110
 		WHERE
-			user_id=$104
+			user_id=$111
 	`
 	_, err := s.db.Exec(
 		query,
@@ -552,6 +573,13 @@ func (s *Storage) UpdateIntegration(integration *model.Integration) error {
 		integration.CuboxAPILink,
 		integration.DiscordEnabled,
 		integration.DiscordWebhookLink,
+		integration.SlackEnabled,
+		integration.SlackWebhookLink,
+		integration.PushoverEnabled,
+		integration.PushoverUser,
+		integration.PushoverToken,
+		integration.PushoverDevice,
+		integration.PushoverPrefix,
 		integration.UserID,
 	)
 
@@ -593,7 +621,8 @@ func (s *Storage) HasSaveEntry(userID int64) (result bool) {
 				raindrop_enabled='t' OR
 				betula_enabled='t' OR
 				cubox_enabled='t' OR
-				discord_enabled='t'
+				discord_enabled='t' OR
+				slack_enabled='t'
 			)
 	`
 	if err := s.db.QueryRow(query, userID).Scan(&result); err != nil {
